Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type LoadTestsServer ¶
type LoadTestsServer struct {
// BeginCreateOrUpdate is the fake for method LoadTestsClient.BeginCreateOrUpdate
// HTTP status codes to indicate success: http.StatusOK, http.StatusCreated
BeginCreateOrUpdate func(ctx context.Context, resourceGroupName string, loadTestName string, loadTestResource armloadtesting.LoadTestResource, options *armloadtesting.LoadTestsClientBeginCreateOrUpdateOptions) (resp azfake.PollerResponder[armloadtesting.LoadTestsClientCreateOrUpdateResponse], errResp azfake.ErrorResponder)
// BeginDelete is the fake for method LoadTestsClient.BeginDelete
// HTTP status codes to indicate success: http.StatusOK, http.StatusAccepted, http.StatusNoContent
BeginDelete func(ctx context.Context, resourceGroupName string, loadTestName string, options *armloadtesting.LoadTestsClientBeginDeleteOptions) (resp azfake.PollerResponder[armloadtesting.LoadTestsClientDeleteResponse], errResp azfake.ErrorResponder)
// Get is the fake for method LoadTestsClient.Get
// HTTP status codes to indicate success: http.StatusOK
Get func(ctx context.Context, resourceGroupName string, loadTestName string, options *armloadtesting.LoadTestsClientGetOptions) (resp azfake.Responder[armloadtesting.LoadTestsClientGetResponse], errResp azfake.ErrorResponder)
// NewListByResourceGroupPager is the fake for method LoadTestsClient.NewListByResourceGroupPager
// HTTP status codes to indicate success: http.StatusOK
NewListByResourceGroupPager func(resourceGroupName string, options *armloadtesting.LoadTestsClientListByResourceGroupOptions) (resp azfake.PagerResponder[armloadtesting.LoadTestsClientListByResourceGroupResponse])
// NewListBySubscriptionPager is the fake for method LoadTestsClient.NewListBySubscriptionPager
// HTTP status codes to indicate success: http.StatusOK
NewListBySubscriptionPager func(options *armloadtesting.LoadTestsClientListBySubscriptionOptions) (resp azfake.PagerResponder[armloadtesting.LoadTestsClientListBySubscriptionResponse])
// NewListOutboundNetworkDependenciesEndpointsPager is the fake for method LoadTestsClient.NewListOutboundNetworkDependenciesEndpointsPager
// HTTP status codes to indicate success: http.StatusOK
NewListOutboundNetworkDependenciesEndpointsPager func(resourceGroupName string, loadTestName string, options *armloadtesting.LoadTestsClientListOutboundNetworkDependenciesEndpointsOptions) (resp azfake.PagerResponder[armloadtesting.LoadTestsClientListOutboundNetworkDependenciesEndpointsResponse])
// BeginUpdate is the fake for method LoadTestsClient.BeginUpdate
// HTTP status codes to indicate success: http.StatusOK, http.StatusAccepted
BeginUpdate func(ctx context.Context, resourceGroupName string, loadTestName string, loadTestResourcePatchRequestBody armloadtesting.LoadTestResourcePatchRequestBody, options *armloadtesting.LoadTestsClientBeginUpdateOptions) (resp azfake.PollerResponder[armloadtesting.LoadTestsClientUpdateResponse], errResp azfake.ErrorResponder)
}
LoadTestsServer is a fake server for instances of the armloadtesting.LoadTestsClient type.
type LoadTestsServerTransport ¶
type LoadTestsServerTransport struct {
// contains filtered or unexported fields
}
LoadTestsServerTransport connects instances of armloadtesting.LoadTestsClient to instances of LoadTestsServer. Don't use this type directly, use NewLoadTestsServerTransport instead.
func NewLoadTestsServerTransport ¶
func NewLoadTestsServerTransport(srv *LoadTestsServer) *LoadTestsServerTransport
NewLoadTestsServerTransport creates a new instance of LoadTestsServerTransport with the provided implementation. The returned LoadTestsServerTransport instance is connected to an instance of armloadtesting.LoadTestsClient via the azcore.ClientOptions.Transporter field in the client's constructor parameters.
type OperationsServer ¶
type OperationsServer struct {
// NewListPager is the fake for method OperationsClient.NewListPager
// HTTP status codes to indicate success: http.StatusOK
NewListPager func(options *armloadtesting.OperationsClientListOptions) (resp azfake.PagerResponder[armloadtesting.OperationsClientListResponse])
}
OperationsServer is a fake server for instances of the armloadtesting.OperationsClient type.
type OperationsServerTransport ¶
type OperationsServerTransport struct {
// contains filtered or unexported fields
}
OperationsServerTransport connects instances of armloadtesting.OperationsClient to instances of OperationsServer. Don't use this type directly, use NewOperationsServerTransport instead.
func NewOperationsServerTransport ¶
func NewOperationsServerTransport(srv *OperationsServer) *OperationsServerTransport
NewOperationsServerTransport creates a new instance of OperationsServerTransport with the provided implementation. The returned OperationsServerTransport instance is connected to an instance of armloadtesting.OperationsClient via the azcore.ClientOptions.Transporter field in the client's constructor parameters.
type QuotasServer ¶
type QuotasServer struct {
// CheckAvailability is the fake for method QuotasClient.CheckAvailability
// HTTP status codes to indicate success: http.StatusOK
CheckAvailability func(ctx context.Context, location string, quotaBucketName string, quotaBucketRequest armloadtesting.QuotaBucketRequest, options *armloadtesting.QuotasClientCheckAvailabilityOptions) (resp azfake.Responder[armloadtesting.QuotasClientCheckAvailabilityResponse], errResp azfake.ErrorResponder)
// Get is the fake for method QuotasClient.Get
// HTTP status codes to indicate success: http.StatusOK
Get func(ctx context.Context, location string, quotaBucketName string, options *armloadtesting.QuotasClientGetOptions) (resp azfake.Responder[armloadtesting.QuotasClientGetResponse], errResp azfake.ErrorResponder)
// NewListPager is the fake for method QuotasClient.NewListPager
// HTTP status codes to indicate success: http.StatusOK
NewListPager func(location string, options *armloadtesting.QuotasClientListOptions) (resp azfake.PagerResponder[armloadtesting.QuotasClientListResponse])
}
QuotasServer is a fake server for instances of the armloadtesting.QuotasClient type.
type QuotasServerTransport ¶
type QuotasServerTransport struct {
// contains filtered or unexported fields
}
QuotasServerTransport connects instances of armloadtesting.QuotasClient to instances of QuotasServer. Don't use this type directly, use NewQuotasServerTransport instead.
func NewQuotasServerTransport ¶
func NewQuotasServerTransport(srv *QuotasServer) *QuotasServerTransport
NewQuotasServerTransport creates a new instance of QuotasServerTransport with the provided implementation. The returned QuotasServerTransport instance is connected to an instance of armloadtesting.QuotasClient via the azcore.ClientOptions.Transporter field in the client's constructor parameters.
type ServerFactory ¶
type ServerFactory struct {
LoadTestsServer LoadTestsServer
OperationsServer OperationsServer
QuotasServer QuotasServer
}
ServerFactory is a fake server for instances of the armloadtesting.ClientFactory type.
type ServerFactoryTransport ¶
type ServerFactoryTransport struct {
// contains filtered or unexported fields
}
ServerFactoryTransport connects instances of armloadtesting.ClientFactory to instances of ServerFactory. Don't use this type directly, use NewServerFactoryTransport instead.
func NewServerFactoryTransport ¶
func NewServerFactoryTransport(srv *ServerFactory) *ServerFactoryTransport
NewServerFactoryTransport creates a new instance of ServerFactoryTransport with the provided implementation. The returned ServerFactoryTransport instance is connected to an instance of armloadtesting.ClientFactory via the azcore.ClientOptions.Transporter field in the client's constructor parameters.