Documentation
¶
Index ¶
- type AccessControlRecordsServer
- type AccessControlRecordsServerTransport
- type AlertsServer
- type AlertsServerTransport
- type AvailableProviderOperationsServer
- type AvailableProviderOperationsServerTransport
- type BackupScheduleGroupsServer
- type BackupScheduleGroupsServerTransport
- type BackupsServer
- type BackupsServerTransport
- type ChapSettingsServer
- type ChapSettingsServerTransport
- type DevicesServer
- type DevicesServerTransport
- type FileServersServer
- type FileServersServerTransport
- type FileSharesServer
- type FileSharesServerTransport
- type IscsiDisksServer
- type IscsiDisksServerTransport
- type IscsiServersServer
- type IscsiServersServerTransport
- type JobsServer
- type JobsServerTransport
- type ManagersServer
- type ManagersServerTransport
- type ServerFactory
- type ServerFactoryTransport
- type StorageAccountCredentialsServer
- type StorageAccountCredentialsServerTransport
- type StorageDomainsServer
- type StorageDomainsServerTransport
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type AccessControlRecordsServer ¶
type AccessControlRecordsServer struct {
// BeginCreateOrUpdate is the fake for method AccessControlRecordsClient.BeginCreateOrUpdate
// HTTP status codes to indicate success: http.StatusOK, http.StatusAccepted
BeginCreateOrUpdate func(ctx context.Context, accessControlRecordName string, resourceGroupName string, managerName string, accessControlRecord armstorsimple1200series.AccessControlRecord, options *armstorsimple1200series.AccessControlRecordsClientBeginCreateOrUpdateOptions) (resp azfake.PollerResponder[armstorsimple1200series.AccessControlRecordsClientCreateOrUpdateResponse], errResp azfake.ErrorResponder)
// BeginDelete is the fake for method AccessControlRecordsClient.BeginDelete
// HTTP status codes to indicate success: http.StatusAccepted, http.StatusNoContent
BeginDelete func(ctx context.Context, accessControlRecordName string, resourceGroupName string, managerName string, options *armstorsimple1200series.AccessControlRecordsClientBeginDeleteOptions) (resp azfake.PollerResponder[armstorsimple1200series.AccessControlRecordsClientDeleteResponse], errResp azfake.ErrorResponder)
// Get is the fake for method AccessControlRecordsClient.Get
// HTTP status codes to indicate success: http.StatusOK
Get func(ctx context.Context, accessControlRecordName string, resourceGroupName string, managerName string, options *armstorsimple1200series.AccessControlRecordsClientGetOptions) (resp azfake.Responder[armstorsimple1200series.AccessControlRecordsClientGetResponse], errResp azfake.ErrorResponder)
// NewListByManagerPager is the fake for method AccessControlRecordsClient.NewListByManagerPager
// HTTP status codes to indicate success: http.StatusOK
NewListByManagerPager func(resourceGroupName string, managerName string, options *armstorsimple1200series.AccessControlRecordsClientListByManagerOptions) (resp azfake.PagerResponder[armstorsimple1200series.AccessControlRecordsClientListByManagerResponse])
}
AccessControlRecordsServer is a fake server for instances of the armstorsimple1200series.AccessControlRecordsClient type.
type AccessControlRecordsServerTransport ¶
type AccessControlRecordsServerTransport struct {
// contains filtered or unexported fields
}
AccessControlRecordsServerTransport connects instances of armstorsimple1200series.AccessControlRecordsClient to instances of AccessControlRecordsServer. Don't use this type directly, use NewAccessControlRecordsServerTransport instead.
func NewAccessControlRecordsServerTransport ¶
func NewAccessControlRecordsServerTransport(srv *AccessControlRecordsServer) *AccessControlRecordsServerTransport
NewAccessControlRecordsServerTransport creates a new instance of AccessControlRecordsServerTransport with the provided implementation. The returned AccessControlRecordsServerTransport instance is connected to an instance of armstorsimple1200series.AccessControlRecordsClient via the azcore.ClientOptions.Transporter field in the client's constructor parameters.
type AlertsServer ¶
type AlertsServer struct {
// Clear is the fake for method AlertsClient.Clear
// HTTP status codes to indicate success: http.StatusNoContent
Clear func(ctx context.Context, resourceGroupName string, managerName string, request armstorsimple1200series.ClearAlertRequest, options *armstorsimple1200series.AlertsClientClearOptions) (resp azfake.Responder[armstorsimple1200series.AlertsClientClearResponse], errResp azfake.ErrorResponder)
// NewListByManagerPager is the fake for method AlertsClient.NewListByManagerPager
// HTTP status codes to indicate success: http.StatusOK
NewListByManagerPager func(resourceGroupName string, managerName string, options *armstorsimple1200series.AlertsClientListByManagerOptions) (resp azfake.PagerResponder[armstorsimple1200series.AlertsClientListByManagerResponse])
// SendTestEmail is the fake for method AlertsClient.SendTestEmail
// HTTP status codes to indicate success: http.StatusNoContent
SendTestEmail func(ctx context.Context, deviceName string, resourceGroupName string, managerName string, request armstorsimple1200series.SendTestAlertEmailRequest, options *armstorsimple1200series.AlertsClientSendTestEmailOptions) (resp azfake.Responder[armstorsimple1200series.AlertsClientSendTestEmailResponse], errResp azfake.ErrorResponder)
}
AlertsServer is a fake server for instances of the armstorsimple1200series.AlertsClient type.
type AlertsServerTransport ¶
type AlertsServerTransport struct {
// contains filtered or unexported fields
}
AlertsServerTransport connects instances of armstorsimple1200series.AlertsClient to instances of AlertsServer. Don't use this type directly, use NewAlertsServerTransport instead.
func NewAlertsServerTransport ¶
func NewAlertsServerTransport(srv *AlertsServer) *AlertsServerTransport
NewAlertsServerTransport creates a new instance of AlertsServerTransport with the provided implementation. The returned AlertsServerTransport instance is connected to an instance of armstorsimple1200series.AlertsClient via the azcore.ClientOptions.Transporter field in the client's constructor parameters.
type AvailableProviderOperationsServer ¶
type AvailableProviderOperationsServer struct {
// NewListPager is the fake for method AvailableProviderOperationsClient.NewListPager
// HTTP status codes to indicate success: http.StatusOK
NewListPager func(options *armstorsimple1200series.AvailableProviderOperationsClientListOptions) (resp azfake.PagerResponder[armstorsimple1200series.AvailableProviderOperationsClientListResponse])
}
AvailableProviderOperationsServer is a fake server for instances of the armstorsimple1200series.AvailableProviderOperationsClient type.
type AvailableProviderOperationsServerTransport ¶
type AvailableProviderOperationsServerTransport struct {
// contains filtered or unexported fields
}
AvailableProviderOperationsServerTransport connects instances of armstorsimple1200series.AvailableProviderOperationsClient to instances of AvailableProviderOperationsServer. Don't use this type directly, use NewAvailableProviderOperationsServerTransport instead.
func NewAvailableProviderOperationsServerTransport ¶
func NewAvailableProviderOperationsServerTransport(srv *AvailableProviderOperationsServer) *AvailableProviderOperationsServerTransport
NewAvailableProviderOperationsServerTransport creates a new instance of AvailableProviderOperationsServerTransport with the provided implementation. The returned AvailableProviderOperationsServerTransport instance is connected to an instance of armstorsimple1200series.AvailableProviderOperationsClient via the azcore.ClientOptions.Transporter field in the client's constructor parameters.
type BackupScheduleGroupsServer ¶
type BackupScheduleGroupsServer struct {
// BeginCreateOrUpdate is the fake for method BackupScheduleGroupsClient.BeginCreateOrUpdate
// HTTP status codes to indicate success: http.StatusOK, http.StatusAccepted
BeginCreateOrUpdate func(ctx context.Context, deviceName string, scheduleGroupName string, resourceGroupName string, managerName string, scheduleGroup armstorsimple1200series.BackupScheduleGroup, options *armstorsimple1200series.BackupScheduleGroupsClientBeginCreateOrUpdateOptions) (resp azfake.PollerResponder[armstorsimple1200series.BackupScheduleGroupsClientCreateOrUpdateResponse], errResp azfake.ErrorResponder)
// BeginDelete is the fake for method BackupScheduleGroupsClient.BeginDelete
// HTTP status codes to indicate success: http.StatusAccepted, http.StatusNoContent
BeginDelete func(ctx context.Context, deviceName string, scheduleGroupName string, resourceGroupName string, managerName string, options *armstorsimple1200series.BackupScheduleGroupsClientBeginDeleteOptions) (resp azfake.PollerResponder[armstorsimple1200series.BackupScheduleGroupsClientDeleteResponse], errResp azfake.ErrorResponder)
// Get is the fake for method BackupScheduleGroupsClient.Get
// HTTP status codes to indicate success: http.StatusOK
Get func(ctx context.Context, deviceName string, scheduleGroupName string, resourceGroupName string, managerName string, options *armstorsimple1200series.BackupScheduleGroupsClientGetOptions) (resp azfake.Responder[armstorsimple1200series.BackupScheduleGroupsClientGetResponse], errResp azfake.ErrorResponder)
// NewListByDevicePager is the fake for method BackupScheduleGroupsClient.NewListByDevicePager
// HTTP status codes to indicate success: http.StatusOK
NewListByDevicePager func(deviceName string, resourceGroupName string, managerName string, options *armstorsimple1200series.BackupScheduleGroupsClientListByDeviceOptions) (resp azfake.PagerResponder[armstorsimple1200series.BackupScheduleGroupsClientListByDeviceResponse])
}
BackupScheduleGroupsServer is a fake server for instances of the armstorsimple1200series.BackupScheduleGroupsClient type.
type BackupScheduleGroupsServerTransport ¶
type BackupScheduleGroupsServerTransport struct {
// contains filtered or unexported fields
}
BackupScheduleGroupsServerTransport connects instances of armstorsimple1200series.BackupScheduleGroupsClient to instances of BackupScheduleGroupsServer. Don't use this type directly, use NewBackupScheduleGroupsServerTransport instead.
func NewBackupScheduleGroupsServerTransport ¶
func NewBackupScheduleGroupsServerTransport(srv *BackupScheduleGroupsServer) *BackupScheduleGroupsServerTransport
NewBackupScheduleGroupsServerTransport creates a new instance of BackupScheduleGroupsServerTransport with the provided implementation. The returned BackupScheduleGroupsServerTransport instance is connected to an instance of armstorsimple1200series.BackupScheduleGroupsClient via the azcore.ClientOptions.Transporter field in the client's constructor parameters.
type BackupsServer ¶
type BackupsServer struct {
// BeginClone is the fake for method BackupsClient.BeginClone
// HTTP status codes to indicate success: http.StatusOK, http.StatusAccepted
BeginClone func(ctx context.Context, deviceName string, backupName string, elementName string, resourceGroupName string, managerName string, cloneRequest armstorsimple1200series.CloneRequest, options *armstorsimple1200series.BackupsClientBeginCloneOptions) (resp azfake.PollerResponder[armstorsimple1200series.BackupsClientCloneResponse], errResp azfake.ErrorResponder)
// BeginDelete is the fake for method BackupsClient.BeginDelete
// HTTP status codes to indicate success: http.StatusAccepted, http.StatusNoContent
BeginDelete func(ctx context.Context, deviceName string, backupName string, resourceGroupName string, managerName string, options *armstorsimple1200series.BackupsClientBeginDeleteOptions) (resp azfake.PollerResponder[armstorsimple1200series.BackupsClientDeleteResponse], errResp azfake.ErrorResponder)
// NewListByDevicePager is the fake for method BackupsClient.NewListByDevicePager
// HTTP status codes to indicate success: http.StatusOK
NewListByDevicePager func(deviceName string, resourceGroupName string, managerName string, options *armstorsimple1200series.BackupsClientListByDeviceOptions) (resp azfake.PagerResponder[armstorsimple1200series.BackupsClientListByDeviceResponse])
// NewListByManagerPager is the fake for method BackupsClient.NewListByManagerPager
// HTTP status codes to indicate success: http.StatusOK
NewListByManagerPager func(resourceGroupName string, managerName string, options *armstorsimple1200series.BackupsClientListByManagerOptions) (resp azfake.PagerResponder[armstorsimple1200series.BackupsClientListByManagerResponse])
}
BackupsServer is a fake server for instances of the armstorsimple1200series.BackupsClient type.
type BackupsServerTransport ¶
type BackupsServerTransport struct {
// contains filtered or unexported fields
}
BackupsServerTransport connects instances of armstorsimple1200series.BackupsClient to instances of BackupsServer. Don't use this type directly, use NewBackupsServerTransport instead.
func NewBackupsServerTransport ¶
func NewBackupsServerTransport(srv *BackupsServer) *BackupsServerTransport
NewBackupsServerTransport creates a new instance of BackupsServerTransport with the provided implementation. The returned BackupsServerTransport instance is connected to an instance of armstorsimple1200series.BackupsClient via the azcore.ClientOptions.Transporter field in the client's constructor parameters.
type ChapSettingsServer ¶
type ChapSettingsServer struct {
// BeginCreateOrUpdate is the fake for method ChapSettingsClient.BeginCreateOrUpdate
// HTTP status codes to indicate success: http.StatusOK, http.StatusAccepted
BeginCreateOrUpdate func(ctx context.Context, deviceName string, chapUserName string, resourceGroupName string, managerName string, chapSetting armstorsimple1200series.ChapSettings, options *armstorsimple1200series.ChapSettingsClientBeginCreateOrUpdateOptions) (resp azfake.PollerResponder[armstorsimple1200series.ChapSettingsClientCreateOrUpdateResponse], errResp azfake.ErrorResponder)
// BeginDelete is the fake for method ChapSettingsClient.BeginDelete
// HTTP status codes to indicate success: http.StatusAccepted, http.StatusNoContent
BeginDelete func(ctx context.Context, deviceName string, chapUserName string, resourceGroupName string, managerName string, options *armstorsimple1200series.ChapSettingsClientBeginDeleteOptions) (resp azfake.PollerResponder[armstorsimple1200series.ChapSettingsClientDeleteResponse], errResp azfake.ErrorResponder)
// Get is the fake for method ChapSettingsClient.Get
// HTTP status codes to indicate success: http.StatusOK
Get func(ctx context.Context, deviceName string, chapUserName string, resourceGroupName string, managerName string, options *armstorsimple1200series.ChapSettingsClientGetOptions) (resp azfake.Responder[armstorsimple1200series.ChapSettingsClientGetResponse], errResp azfake.ErrorResponder)
// NewListByDevicePager is the fake for method ChapSettingsClient.NewListByDevicePager
// HTTP status codes to indicate success: http.StatusOK
NewListByDevicePager func(deviceName string, resourceGroupName string, managerName string, options *armstorsimple1200series.ChapSettingsClientListByDeviceOptions) (resp azfake.PagerResponder[armstorsimple1200series.ChapSettingsClientListByDeviceResponse])
}
ChapSettingsServer is a fake server for instances of the armstorsimple1200series.ChapSettingsClient type.
type ChapSettingsServerTransport ¶
type ChapSettingsServerTransport struct {
// contains filtered or unexported fields
}
ChapSettingsServerTransport connects instances of armstorsimple1200series.ChapSettingsClient to instances of ChapSettingsServer. Don't use this type directly, use NewChapSettingsServerTransport instead.
func NewChapSettingsServerTransport ¶
func NewChapSettingsServerTransport(srv *ChapSettingsServer) *ChapSettingsServerTransport
NewChapSettingsServerTransport creates a new instance of ChapSettingsServerTransport with the provided implementation. The returned ChapSettingsServerTransport instance is connected to an instance of armstorsimple1200series.ChapSettingsClient via the azcore.ClientOptions.Transporter field in the client's constructor parameters.
type DevicesServer ¶
type DevicesServer struct {
// BeginCreateOrUpdateAlertSettings is the fake for method DevicesClient.BeginCreateOrUpdateAlertSettings
// HTTP status codes to indicate success: http.StatusOK, http.StatusAccepted
BeginCreateOrUpdateAlertSettings func(ctx context.Context, deviceName string, resourceGroupName string, managerName string, alertSettings armstorsimple1200series.AlertSettings, options *armstorsimple1200series.DevicesClientBeginCreateOrUpdateAlertSettingsOptions) (resp azfake.PollerResponder[armstorsimple1200series.DevicesClientCreateOrUpdateAlertSettingsResponse], errResp azfake.ErrorResponder)
// BeginCreateOrUpdateSecuritySettings is the fake for method DevicesClient.BeginCreateOrUpdateSecuritySettings
// HTTP status codes to indicate success: http.StatusAccepted, http.StatusNoContent
BeginCreateOrUpdateSecuritySettings func(ctx context.Context, deviceName string, resourceGroupName string, managerName string, securitySettings armstorsimple1200series.SecuritySettings, options *armstorsimple1200series.DevicesClientBeginCreateOrUpdateSecuritySettingsOptions) (resp azfake.PollerResponder[armstorsimple1200series.DevicesClientCreateOrUpdateSecuritySettingsResponse], errResp azfake.ErrorResponder)
// BeginDeactivate is the fake for method DevicesClient.BeginDeactivate
// HTTP status codes to indicate success: http.StatusAccepted, http.StatusNoContent
BeginDeactivate func(ctx context.Context, deviceName string, resourceGroupName string, managerName string, options *armstorsimple1200series.DevicesClientBeginDeactivateOptions) (resp azfake.PollerResponder[armstorsimple1200series.DevicesClientDeactivateResponse], errResp azfake.ErrorResponder)
// BeginDelete is the fake for method DevicesClient.BeginDelete
// HTTP status codes to indicate success: http.StatusAccepted, http.StatusNoContent
BeginDelete func(ctx context.Context, deviceName string, resourceGroupName string, managerName string, options *armstorsimple1200series.DevicesClientBeginDeleteOptions) (resp azfake.PollerResponder[armstorsimple1200series.DevicesClientDeleteResponse], errResp azfake.ErrorResponder)
// BeginDownloadUpdates is the fake for method DevicesClient.BeginDownloadUpdates
// HTTP status codes to indicate success: http.StatusAccepted, http.StatusNoContent
BeginDownloadUpdates func(ctx context.Context, deviceName string, resourceGroupName string, managerName string, options *armstorsimple1200series.DevicesClientBeginDownloadUpdatesOptions) (resp azfake.PollerResponder[armstorsimple1200series.DevicesClientDownloadUpdatesResponse], errResp azfake.ErrorResponder)
// BeginFailover is the fake for method DevicesClient.BeginFailover
// HTTP status codes to indicate success: http.StatusAccepted, http.StatusNoContent
BeginFailover func(ctx context.Context, deviceName string, resourceGroupName string, managerName string, failoverRequest armstorsimple1200series.FailoverRequest, options *armstorsimple1200series.DevicesClientBeginFailoverOptions) (resp azfake.PollerResponder[armstorsimple1200series.DevicesClientFailoverResponse], errResp azfake.ErrorResponder)
// Get is the fake for method DevicesClient.Get
// HTTP status codes to indicate success: http.StatusOK
Get func(ctx context.Context, deviceName string, resourceGroupName string, managerName string, options *armstorsimple1200series.DevicesClientGetOptions) (resp azfake.Responder[armstorsimple1200series.DevicesClientGetResponse], errResp azfake.ErrorResponder)
// GetAlertSettings is the fake for method DevicesClient.GetAlertSettings
// HTTP status codes to indicate success: http.StatusOK
GetAlertSettings func(ctx context.Context, deviceName string, resourceGroupName string, managerName string, options *armstorsimple1200series.DevicesClientGetAlertSettingsOptions) (resp azfake.Responder[armstorsimple1200series.DevicesClientGetAlertSettingsResponse], errResp azfake.ErrorResponder)
// GetNetworkSettings is the fake for method DevicesClient.GetNetworkSettings
// HTTP status codes to indicate success: http.StatusOK
GetNetworkSettings func(ctx context.Context, deviceName string, resourceGroupName string, managerName string, options *armstorsimple1200series.DevicesClientGetNetworkSettingsOptions) (resp azfake.Responder[armstorsimple1200series.DevicesClientGetNetworkSettingsResponse], errResp azfake.ErrorResponder)
// GetTimeSettings is the fake for method DevicesClient.GetTimeSettings
// HTTP status codes to indicate success: http.StatusOK
GetTimeSettings func(ctx context.Context, deviceName string, resourceGroupName string, managerName string, options *armstorsimple1200series.DevicesClientGetTimeSettingsOptions) (resp azfake.Responder[armstorsimple1200series.DevicesClientGetTimeSettingsResponse], errResp azfake.ErrorResponder)
// GetUpdateSummary is the fake for method DevicesClient.GetUpdateSummary
// HTTP status codes to indicate success: http.StatusOK
GetUpdateSummary func(ctx context.Context, deviceName string, resourceGroupName string, managerName string, options *armstorsimple1200series.DevicesClientGetUpdateSummaryOptions) (resp azfake.Responder[armstorsimple1200series.DevicesClientGetUpdateSummaryResponse], errResp azfake.ErrorResponder)
// BeginInstallUpdates is the fake for method DevicesClient.BeginInstallUpdates
// HTTP status codes to indicate success: http.StatusAccepted, http.StatusNoContent
BeginInstallUpdates func(ctx context.Context, deviceName string, resourceGroupName string, managerName string, options *armstorsimple1200series.DevicesClientBeginInstallUpdatesOptions) (resp azfake.PollerResponder[armstorsimple1200series.DevicesClientInstallUpdatesResponse], errResp azfake.ErrorResponder)
// NewListByManagerPager is the fake for method DevicesClient.NewListByManagerPager
// HTTP status codes to indicate success: http.StatusOK
NewListByManagerPager func(resourceGroupName string, managerName string, options *armstorsimple1200series.DevicesClientListByManagerOptions) (resp azfake.PagerResponder[armstorsimple1200series.DevicesClientListByManagerResponse])
// NewListFailoverTargetPager is the fake for method DevicesClient.NewListFailoverTargetPager
// HTTP status codes to indicate success: http.StatusOK
NewListFailoverTargetPager func(deviceName string, resourceGroupName string, managerName string, options *armstorsimple1200series.DevicesClientListFailoverTargetOptions) (resp azfake.PagerResponder[armstorsimple1200series.DevicesClientListFailoverTargetResponse])
// NewListMetricDefinitionPager is the fake for method DevicesClient.NewListMetricDefinitionPager
// HTTP status codes to indicate success: http.StatusOK
NewListMetricDefinitionPager func(deviceName string, resourceGroupName string, managerName string, options *armstorsimple1200series.DevicesClientListMetricDefinitionOptions) (resp azfake.PagerResponder[armstorsimple1200series.DevicesClientListMetricDefinitionResponse])
// NewListMetricsPager is the fake for method DevicesClient.NewListMetricsPager
// HTTP status codes to indicate success: http.StatusOK
NewListMetricsPager func(deviceName string, resourceGroupName string, managerName string, options *armstorsimple1200series.DevicesClientListMetricsOptions) (resp azfake.PagerResponder[armstorsimple1200series.DevicesClientListMetricsResponse])
// BeginPatch is the fake for method DevicesClient.BeginPatch
// HTTP status codes to indicate success: http.StatusOK, http.StatusAccepted
BeginPatch func(ctx context.Context, deviceName string, resourceGroupName string, managerName string, devicePatch armstorsimple1200series.DevicePatch, options *armstorsimple1200series.DevicesClientBeginPatchOptions) (resp azfake.PollerResponder[armstorsimple1200series.DevicesClientPatchResponse], errResp azfake.ErrorResponder)
// BeginScanForUpdates is the fake for method DevicesClient.BeginScanForUpdates
// HTTP status codes to indicate success: http.StatusAccepted, http.StatusNoContent
BeginScanForUpdates func(ctx context.Context, deviceName string, resourceGroupName string, managerName string, options *armstorsimple1200series.DevicesClientBeginScanForUpdatesOptions) (resp azfake.PollerResponder[armstorsimple1200series.DevicesClientScanForUpdatesResponse], errResp azfake.ErrorResponder)
}
DevicesServer is a fake server for instances of the armstorsimple1200series.DevicesClient type.
type DevicesServerTransport ¶
type DevicesServerTransport struct {
// contains filtered or unexported fields
}
DevicesServerTransport connects instances of armstorsimple1200series.DevicesClient to instances of DevicesServer. Don't use this type directly, use NewDevicesServerTransport instead.
func NewDevicesServerTransport ¶
func NewDevicesServerTransport(srv *DevicesServer) *DevicesServerTransport
NewDevicesServerTransport creates a new instance of DevicesServerTransport with the provided implementation. The returned DevicesServerTransport instance is connected to an instance of armstorsimple1200series.DevicesClient via the azcore.ClientOptions.Transporter field in the client's constructor parameters.
type FileServersServer ¶
type FileServersServer struct {
// BeginBackupNow is the fake for method FileServersClient.BeginBackupNow
// HTTP status codes to indicate success: http.StatusAccepted, http.StatusNoContent
BeginBackupNow func(ctx context.Context, deviceName string, fileServerName string, resourceGroupName string, managerName string, options *armstorsimple1200series.FileServersClientBeginBackupNowOptions) (resp azfake.PollerResponder[armstorsimple1200series.FileServersClientBackupNowResponse], errResp azfake.ErrorResponder)
// BeginCreateOrUpdate is the fake for method FileServersClient.BeginCreateOrUpdate
// HTTP status codes to indicate success: http.StatusOK, http.StatusAccepted
BeginCreateOrUpdate func(ctx context.Context, deviceName string, fileServerName string, resourceGroupName string, managerName string, fileServer armstorsimple1200series.FileServer, options *armstorsimple1200series.FileServersClientBeginCreateOrUpdateOptions) (resp azfake.PollerResponder[armstorsimple1200series.FileServersClientCreateOrUpdateResponse], errResp azfake.ErrorResponder)
// BeginDelete is the fake for method FileServersClient.BeginDelete
// HTTP status codes to indicate success: http.StatusAccepted, http.StatusNoContent
BeginDelete func(ctx context.Context, deviceName string, fileServerName string, resourceGroupName string, managerName string, options *armstorsimple1200series.FileServersClientBeginDeleteOptions) (resp azfake.PollerResponder[armstorsimple1200series.FileServersClientDeleteResponse], errResp azfake.ErrorResponder)
// Get is the fake for method FileServersClient.Get
// HTTP status codes to indicate success: http.StatusOK
Get func(ctx context.Context, deviceName string, fileServerName string, resourceGroupName string, managerName string, options *armstorsimple1200series.FileServersClientGetOptions) (resp azfake.Responder[armstorsimple1200series.FileServersClientGetResponse], errResp azfake.ErrorResponder)
// NewListByDevicePager is the fake for method FileServersClient.NewListByDevicePager
// HTTP status codes to indicate success: http.StatusOK
NewListByDevicePager func(deviceName string, resourceGroupName string, managerName string, options *armstorsimple1200series.FileServersClientListByDeviceOptions) (resp azfake.PagerResponder[armstorsimple1200series.FileServersClientListByDeviceResponse])
// NewListByManagerPager is the fake for method FileServersClient.NewListByManagerPager
// HTTP status codes to indicate success: http.StatusOK
NewListByManagerPager func(resourceGroupName string, managerName string, options *armstorsimple1200series.FileServersClientListByManagerOptions) (resp azfake.PagerResponder[armstorsimple1200series.FileServersClientListByManagerResponse])
// NewListMetricDefinitionPager is the fake for method FileServersClient.NewListMetricDefinitionPager
// HTTP status codes to indicate success: http.StatusOK
NewListMetricDefinitionPager func(deviceName string, fileServerName string, resourceGroupName string, managerName string, options *armstorsimple1200series.FileServersClientListMetricDefinitionOptions) (resp azfake.PagerResponder[armstorsimple1200series.FileServersClientListMetricDefinitionResponse])
// NewListMetricsPager is the fake for method FileServersClient.NewListMetricsPager
// HTTP status codes to indicate success: http.StatusOK
NewListMetricsPager func(deviceName string, fileServerName string, resourceGroupName string, managerName string, options *armstorsimple1200series.FileServersClientListMetricsOptions) (resp azfake.PagerResponder[armstorsimple1200series.FileServersClientListMetricsResponse])
}
FileServersServer is a fake server for instances of the armstorsimple1200series.FileServersClient type.
type FileServersServerTransport ¶
type FileServersServerTransport struct {
// contains filtered or unexported fields
}
FileServersServerTransport connects instances of armstorsimple1200series.FileServersClient to instances of FileServersServer. Don't use this type directly, use NewFileServersServerTransport instead.
func NewFileServersServerTransport ¶
func NewFileServersServerTransport(srv *FileServersServer) *FileServersServerTransport
NewFileServersServerTransport creates a new instance of FileServersServerTransport with the provided implementation. The returned FileServersServerTransport instance is connected to an instance of armstorsimple1200series.FileServersClient via the azcore.ClientOptions.Transporter field in the client's constructor parameters.
type FileSharesServer ¶
type FileSharesServer struct {
// HTTP status codes to indicate success: http.StatusOK, http.StatusAccepted
BeginCreateOrUpdate func(ctx context.Context, deviceName string, fileServerName string, shareName string, resourceGroupName string, managerName string, fileShare armstorsimple1200series.FileShare, options *armstorsimple1200series.FileSharesClientBeginCreateOrUpdateOptions) (resp azfake.PollerResponder[armstorsimple1200series.FileSharesClientCreateOrUpdateResponse], errResp azfake.ErrorResponder)
// HTTP status codes to indicate success: http.StatusAccepted, http.StatusNoContent
BeginDelete func(ctx context.Context, deviceName string, fileServerName string, shareName string, resourceGroupName string, managerName string, options *armstorsimple1200series.FileSharesClientBeginDeleteOptions) (resp azfake.PollerResponder[armstorsimple1200series.FileSharesClientDeleteResponse], errResp azfake.ErrorResponder)
// HTTP status codes to indicate success: http.StatusOK
Get func(ctx context.Context, deviceName string, fileServerName string, shareName string, resourceGroupName string, managerName string, options *armstorsimple1200series.FileSharesClientGetOptions) (resp azfake.Responder[armstorsimple1200series.FileSharesClientGetResponse], errResp azfake.ErrorResponder)
// HTTP status codes to indicate success: http.StatusOK
NewListByDevicePager func(deviceName string, resourceGroupName string, managerName string, options *armstorsimple1200series.FileSharesClientListByDeviceOptions) (resp azfake.PagerResponder[armstorsimple1200series.FileSharesClientListByDeviceResponse])
// HTTP status codes to indicate success: http.StatusOK
NewListByFileServerPager func(deviceName string, fileServerName string, resourceGroupName string, managerName string, options *armstorsimple1200series.FileSharesClientListByFileServerOptions) (resp azfake.PagerResponder[armstorsimple1200series.FileSharesClientListByFileServerResponse])
// HTTP status codes to indicate success: http.StatusOK
NewListMetricDefinitionPager func(deviceName string, fileServerName string, shareName string, resourceGroupName string, managerName string, options *armstorsimple1200series.FileSharesClientListMetricDefinitionOptions) (resp azfake.PagerResponder[armstorsimple1200series.FileSharesClientListMetricDefinitionResponse])
// HTTP status codes to indicate success: http.StatusOK
NewListMetricsPager func(deviceName string, fileServerName string, shareName string, resourceGroupName string, managerName string, options *armstorsimple1200series.FileSharesClientListMetricsOptions) (resp azfake.PagerResponder[armstorsimple1200series.FileSharesClientListMetricsResponse])
}
FileSharesServer is a fake server for instances of the armstorsimple1200series.FileSharesClient type.
type FileSharesServerTransport ¶
type FileSharesServerTransport struct {
// contains filtered or unexported fields
}
FileSharesServerTransport connects instances of armstorsimple1200series.FileSharesClient to instances of FileSharesServer. Don't use this type directly, use NewFileSharesServerTransport instead.
func NewFileSharesServerTransport ¶
func NewFileSharesServerTransport(srv *FileSharesServer) *FileSharesServerTransport
NewFileSharesServerTransport creates a new instance of FileSharesServerTransport with the provided implementation. The returned FileSharesServerTransport instance is connected to an instance of armstorsimple1200series.FileSharesClient via the azcore.ClientOptions.Transporter field in the client's constructor parameters.
type IscsiDisksServer ¶
type IscsiDisksServer struct {
// BeginCreateOrUpdate is the fake for method IscsiDisksClient.BeginCreateOrUpdate
// HTTP status codes to indicate success: http.StatusOK, http.StatusAccepted
BeginCreateOrUpdate func(ctx context.Context, deviceName string, iscsiServerName string, diskName string, resourceGroupName string, managerName string, iscsiDisk armstorsimple1200series.ISCSIDisk, options *armstorsimple1200series.IscsiDisksClientBeginCreateOrUpdateOptions) (resp azfake.PollerResponder[armstorsimple1200series.IscsiDisksClientCreateOrUpdateResponse], errResp azfake.ErrorResponder)
// BeginDelete is the fake for method IscsiDisksClient.BeginDelete
// HTTP status codes to indicate success: http.StatusAccepted, http.StatusNoContent
BeginDelete func(ctx context.Context, deviceName string, iscsiServerName string, diskName string, resourceGroupName string, managerName string, options *armstorsimple1200series.IscsiDisksClientBeginDeleteOptions) (resp azfake.PollerResponder[armstorsimple1200series.IscsiDisksClientDeleteResponse], errResp azfake.ErrorResponder)
// Get is the fake for method IscsiDisksClient.Get
// HTTP status codes to indicate success: http.StatusOK
Get func(ctx context.Context, deviceName string, iscsiServerName string, diskName string, resourceGroupName string, managerName string, options *armstorsimple1200series.IscsiDisksClientGetOptions) (resp azfake.Responder[armstorsimple1200series.IscsiDisksClientGetResponse], errResp azfake.ErrorResponder)
// NewListByDevicePager is the fake for method IscsiDisksClient.NewListByDevicePager
// HTTP status codes to indicate success: http.StatusOK
NewListByDevicePager func(deviceName string, resourceGroupName string, managerName string, options *armstorsimple1200series.IscsiDisksClientListByDeviceOptions) (resp azfake.PagerResponder[armstorsimple1200series.IscsiDisksClientListByDeviceResponse])
// NewListByIscsiServerPager is the fake for method IscsiDisksClient.NewListByIscsiServerPager
// HTTP status codes to indicate success: http.StatusOK
NewListByIscsiServerPager func(deviceName string, iscsiServerName string, resourceGroupName string, managerName string, options *armstorsimple1200series.IscsiDisksClientListByIscsiServerOptions) (resp azfake.PagerResponder[armstorsimple1200series.IscsiDisksClientListByIscsiServerResponse])
// NewListMetricDefinitionPager is the fake for method IscsiDisksClient.NewListMetricDefinitionPager
// HTTP status codes to indicate success: http.StatusOK
NewListMetricDefinitionPager func(deviceName string, iscsiServerName string, diskName string, resourceGroupName string, managerName string, options *armstorsimple1200series.IscsiDisksClientListMetricDefinitionOptions) (resp azfake.PagerResponder[armstorsimple1200series.IscsiDisksClientListMetricDefinitionResponse])
// NewListMetricsPager is the fake for method IscsiDisksClient.NewListMetricsPager
// HTTP status codes to indicate success: http.StatusOK
NewListMetricsPager func(deviceName string, iscsiServerName string, diskName string, resourceGroupName string, managerName string, options *armstorsimple1200series.IscsiDisksClientListMetricsOptions) (resp azfake.PagerResponder[armstorsimple1200series.IscsiDisksClientListMetricsResponse])
}
IscsiDisksServer is a fake server for instances of the armstorsimple1200series.IscsiDisksClient type.
type IscsiDisksServerTransport ¶
type IscsiDisksServerTransport struct {
// contains filtered or unexported fields
}
IscsiDisksServerTransport connects instances of armstorsimple1200series.IscsiDisksClient to instances of IscsiDisksServer. Don't use this type directly, use NewIscsiDisksServerTransport instead.
func NewIscsiDisksServerTransport ¶
func NewIscsiDisksServerTransport(srv *IscsiDisksServer) *IscsiDisksServerTransport
NewIscsiDisksServerTransport creates a new instance of IscsiDisksServerTransport with the provided implementation. The returned IscsiDisksServerTransport instance is connected to an instance of armstorsimple1200series.IscsiDisksClient via the azcore.ClientOptions.Transporter field in the client's constructor parameters.
type IscsiServersServer ¶
type IscsiServersServer struct {
// BeginBackupNow is the fake for method IscsiServersClient.BeginBackupNow
// HTTP status codes to indicate success: http.StatusAccepted, http.StatusNoContent
BeginBackupNow func(ctx context.Context, deviceName string, iscsiServerName string, resourceGroupName string, managerName string, options *armstorsimple1200series.IscsiServersClientBeginBackupNowOptions) (resp azfake.PollerResponder[armstorsimple1200series.IscsiServersClientBackupNowResponse], errResp azfake.ErrorResponder)
// BeginCreateOrUpdate is the fake for method IscsiServersClient.BeginCreateOrUpdate
// HTTP status codes to indicate success: http.StatusOK, http.StatusAccepted
BeginCreateOrUpdate func(ctx context.Context, deviceName string, iscsiServerName string, resourceGroupName string, managerName string, iscsiServer armstorsimple1200series.ISCSIServer, options *armstorsimple1200series.IscsiServersClientBeginCreateOrUpdateOptions) (resp azfake.PollerResponder[armstorsimple1200series.IscsiServersClientCreateOrUpdateResponse], errResp azfake.ErrorResponder)
// BeginDelete is the fake for method IscsiServersClient.BeginDelete
// HTTP status codes to indicate success: http.StatusAccepted, http.StatusNoContent
BeginDelete func(ctx context.Context, deviceName string, iscsiServerName string, resourceGroupName string, managerName string, options *armstorsimple1200series.IscsiServersClientBeginDeleteOptions) (resp azfake.PollerResponder[armstorsimple1200series.IscsiServersClientDeleteResponse], errResp azfake.ErrorResponder)
// Get is the fake for method IscsiServersClient.Get
// HTTP status codes to indicate success: http.StatusOK
Get func(ctx context.Context, deviceName string, iscsiServerName string, resourceGroupName string, managerName string, options *armstorsimple1200series.IscsiServersClientGetOptions) (resp azfake.Responder[armstorsimple1200series.IscsiServersClientGetResponse], errResp azfake.ErrorResponder)
// NewListByDevicePager is the fake for method IscsiServersClient.NewListByDevicePager
// HTTP status codes to indicate success: http.StatusOK
NewListByDevicePager func(deviceName string, resourceGroupName string, managerName string, options *armstorsimple1200series.IscsiServersClientListByDeviceOptions) (resp azfake.PagerResponder[armstorsimple1200series.IscsiServersClientListByDeviceResponse])
// NewListByManagerPager is the fake for method IscsiServersClient.NewListByManagerPager
// HTTP status codes to indicate success: http.StatusOK
NewListByManagerPager func(resourceGroupName string, managerName string, options *armstorsimple1200series.IscsiServersClientListByManagerOptions) (resp azfake.PagerResponder[armstorsimple1200series.IscsiServersClientListByManagerResponse])
// NewListMetricDefinitionPager is the fake for method IscsiServersClient.NewListMetricDefinitionPager
// HTTP status codes to indicate success: http.StatusOK
NewListMetricDefinitionPager func(deviceName string, iscsiServerName string, resourceGroupName string, managerName string, options *armstorsimple1200series.IscsiServersClientListMetricDefinitionOptions) (resp azfake.PagerResponder[armstorsimple1200series.IscsiServersClientListMetricDefinitionResponse])
// NewListMetricsPager is the fake for method IscsiServersClient.NewListMetricsPager
// HTTP status codes to indicate success: http.StatusOK
NewListMetricsPager func(deviceName string, iscsiServerName string, resourceGroupName string, managerName string, options *armstorsimple1200series.IscsiServersClientListMetricsOptions) (resp azfake.PagerResponder[armstorsimple1200series.IscsiServersClientListMetricsResponse])
}
IscsiServersServer is a fake server for instances of the armstorsimple1200series.IscsiServersClient type.
type IscsiServersServerTransport ¶
type IscsiServersServerTransport struct {
// contains filtered or unexported fields
}
IscsiServersServerTransport connects instances of armstorsimple1200series.IscsiServersClient to instances of IscsiServersServer. Don't use this type directly, use NewIscsiServersServerTransport instead.
func NewIscsiServersServerTransport ¶
func NewIscsiServersServerTransport(srv *IscsiServersServer) *IscsiServersServerTransport
NewIscsiServersServerTransport creates a new instance of IscsiServersServerTransport with the provided implementation. The returned IscsiServersServerTransport instance is connected to an instance of armstorsimple1200series.IscsiServersClient via the azcore.ClientOptions.Transporter field in the client's constructor parameters.
type JobsServer ¶
type JobsServer struct {
// Get is the fake for method JobsClient.Get
// HTTP status codes to indicate success: http.StatusOK
Get func(ctx context.Context, deviceName string, jobName string, resourceGroupName string, managerName string, options *armstorsimple1200series.JobsClientGetOptions) (resp azfake.Responder[armstorsimple1200series.JobsClientGetResponse], errResp azfake.ErrorResponder)
// NewListByDevicePager is the fake for method JobsClient.NewListByDevicePager
// HTTP status codes to indicate success: http.StatusOK
NewListByDevicePager func(deviceName string, resourceGroupName string, managerName string, options *armstorsimple1200series.JobsClientListByDeviceOptions) (resp azfake.PagerResponder[armstorsimple1200series.JobsClientListByDeviceResponse])
// NewListByManagerPager is the fake for method JobsClient.NewListByManagerPager
// HTTP status codes to indicate success: http.StatusOK
NewListByManagerPager func(resourceGroupName string, managerName string, options *armstorsimple1200series.JobsClientListByManagerOptions) (resp azfake.PagerResponder[armstorsimple1200series.JobsClientListByManagerResponse])
}
JobsServer is a fake server for instances of the armstorsimple1200series.JobsClient type.
type JobsServerTransport ¶
type JobsServerTransport struct {
// contains filtered or unexported fields
}
JobsServerTransport connects instances of armstorsimple1200series.JobsClient to instances of JobsServer. Don't use this type directly, use NewJobsServerTransport instead.
func NewJobsServerTransport ¶
func NewJobsServerTransport(srv *JobsServer) *JobsServerTransport
NewJobsServerTransport creates a new instance of JobsServerTransport with the provided implementation. The returned JobsServerTransport instance is connected to an instance of armstorsimple1200series.JobsClient via the azcore.ClientOptions.Transporter field in the client's constructor parameters.
type ManagersServer ¶
type ManagersServer struct {
// CreateExtendedInfo is the fake for method ManagersClient.CreateExtendedInfo
// HTTP status codes to indicate success: http.StatusOK
CreateExtendedInfo func(ctx context.Context, resourceGroupName string, managerName string, managerExtendedInfo armstorsimple1200series.ManagerExtendedInfo, options *armstorsimple1200series.ManagersClientCreateExtendedInfoOptions) (resp azfake.Responder[armstorsimple1200series.ManagersClientCreateExtendedInfoResponse], errResp azfake.ErrorResponder)
// CreateOrUpdate is the fake for method ManagersClient.CreateOrUpdate
// HTTP status codes to indicate success: http.StatusOK, http.StatusCreated
CreateOrUpdate func(ctx context.Context, resourceGroupName string, managerName string, manager armstorsimple1200series.Manager, options *armstorsimple1200series.ManagersClientCreateOrUpdateOptions) (resp azfake.Responder[armstorsimple1200series.ManagersClientCreateOrUpdateResponse], errResp azfake.ErrorResponder)
// Delete is the fake for method ManagersClient.Delete
// HTTP status codes to indicate success: http.StatusOK, http.StatusNoContent
Delete func(ctx context.Context, resourceGroupName string, managerName string, options *armstorsimple1200series.ManagersClientDeleteOptions) (resp azfake.Responder[armstorsimple1200series.ManagersClientDeleteResponse], errResp azfake.ErrorResponder)
// DeleteExtendedInfo is the fake for method ManagersClient.DeleteExtendedInfo
// HTTP status codes to indicate success: http.StatusNoContent
DeleteExtendedInfo func(ctx context.Context, resourceGroupName string, managerName string, options *armstorsimple1200series.ManagersClientDeleteExtendedInfoOptions) (resp azfake.Responder[armstorsimple1200series.ManagersClientDeleteExtendedInfoResponse], errResp azfake.ErrorResponder)
// Get is the fake for method ManagersClient.Get
// HTTP status codes to indicate success: http.StatusOK
Get func(ctx context.Context, resourceGroupName string, managerName string, options *armstorsimple1200series.ManagersClientGetOptions) (resp azfake.Responder[armstorsimple1200series.ManagersClientGetResponse], errResp azfake.ErrorResponder)
// GetEncryptionKey is the fake for method ManagersClient.GetEncryptionKey
// HTTP status codes to indicate success: http.StatusOK
GetEncryptionKey func(ctx context.Context, resourceGroupName string, managerName string, options *armstorsimple1200series.ManagersClientGetEncryptionKeyOptions) (resp azfake.Responder[armstorsimple1200series.ManagersClientGetEncryptionKeyResponse], errResp azfake.ErrorResponder)
// GetEncryptionSettings is the fake for method ManagersClient.GetEncryptionSettings
// HTTP status codes to indicate success: http.StatusOK
GetEncryptionSettings func(ctx context.Context, resourceGroupName string, managerName string, options *armstorsimple1200series.ManagersClientGetEncryptionSettingsOptions) (resp azfake.Responder[armstorsimple1200series.ManagersClientGetEncryptionSettingsResponse], errResp azfake.ErrorResponder)
// GetExtendedInfo is the fake for method ManagersClient.GetExtendedInfo
// HTTP status codes to indicate success: http.StatusOK
GetExtendedInfo func(ctx context.Context, resourceGroupName string, managerName string, options *armstorsimple1200series.ManagersClientGetExtendedInfoOptions) (resp azfake.Responder[armstorsimple1200series.ManagersClientGetExtendedInfoResponse], errResp azfake.ErrorResponder)
// NewListPager is the fake for method ManagersClient.NewListPager
// HTTP status codes to indicate success: http.StatusOK
NewListPager func(options *armstorsimple1200series.ManagersClientListOptions) (resp azfake.PagerResponder[armstorsimple1200series.ManagersClientListResponse])
// NewListByResourceGroupPager is the fake for method ManagersClient.NewListByResourceGroupPager
// HTTP status codes to indicate success: http.StatusOK
NewListByResourceGroupPager func(resourceGroupName string, options *armstorsimple1200series.ManagersClientListByResourceGroupOptions) (resp azfake.PagerResponder[armstorsimple1200series.ManagersClientListByResourceGroupResponse])
// NewListMetricDefinitionPager is the fake for method ManagersClient.NewListMetricDefinitionPager
// HTTP status codes to indicate success: http.StatusOK
NewListMetricDefinitionPager func(resourceGroupName string, managerName string, options *armstorsimple1200series.ManagersClientListMetricDefinitionOptions) (resp azfake.PagerResponder[armstorsimple1200series.ManagersClientListMetricDefinitionResponse])
// NewListMetricsPager is the fake for method ManagersClient.NewListMetricsPager
// HTTP status codes to indicate success: http.StatusOK
NewListMetricsPager func(resourceGroupName string, managerName string, options *armstorsimple1200series.ManagersClientListMetricsOptions) (resp azfake.PagerResponder[armstorsimple1200series.ManagersClientListMetricsResponse])
// Update is the fake for method ManagersClient.Update
// HTTP status codes to indicate success: http.StatusOK
Update func(ctx context.Context, resourceGroupName string, managerName string, parameters armstorsimple1200series.ManagerPatch, options *armstorsimple1200series.ManagersClientUpdateOptions) (resp azfake.Responder[armstorsimple1200series.ManagersClientUpdateResponse], errResp azfake.ErrorResponder)
// UpdateExtendedInfo is the fake for method ManagersClient.UpdateExtendedInfo
// HTTP status codes to indicate success: http.StatusOK
UpdateExtendedInfo func(ctx context.Context, resourceGroupName string, managerName string, ifMatch string, managerExtendedInfo armstorsimple1200series.ManagerExtendedInfo, options *armstorsimple1200series.ManagersClientUpdateExtendedInfoOptions) (resp azfake.Responder[armstorsimple1200series.ManagersClientUpdateExtendedInfoResponse], errResp azfake.ErrorResponder)
// UploadRegistrationCertificate is the fake for method ManagersClient.UploadRegistrationCertificate
// HTTP status codes to indicate success: http.StatusOK
UploadRegistrationCertificate func(ctx context.Context, certificateName string, resourceGroupName string, managerName string, uploadCertificateRequestrequest armstorsimple1200series.UploadCertificateRequest, options *armstorsimple1200series.ManagersClientUploadRegistrationCertificateOptions) (resp azfake.Responder[armstorsimple1200series.ManagersClientUploadRegistrationCertificateResponse], errResp azfake.ErrorResponder)
}
ManagersServer is a fake server for instances of the armstorsimple1200series.ManagersClient type.
type ManagersServerTransport ¶
type ManagersServerTransport struct {
// contains filtered or unexported fields
}
ManagersServerTransport connects instances of armstorsimple1200series.ManagersClient to instances of ManagersServer. Don't use this type directly, use NewManagersServerTransport instead.
func NewManagersServerTransport ¶
func NewManagersServerTransport(srv *ManagersServer) *ManagersServerTransport
NewManagersServerTransport creates a new instance of ManagersServerTransport with the provided implementation. The returned ManagersServerTransport instance is connected to an instance of armstorsimple1200series.ManagersClient via the azcore.ClientOptions.Transporter field in the client's constructor parameters.
type ServerFactory ¶
type ServerFactory struct {
AccessControlRecordsServer AccessControlRecordsServer
AlertsServer AlertsServer
AvailableProviderOperationsServer AvailableProviderOperationsServer
BackupScheduleGroupsServer BackupScheduleGroupsServer
BackupsServer BackupsServer
ChapSettingsServer ChapSettingsServer
DevicesServer DevicesServer
FileServersServer FileServersServer
IscsiDisksServer IscsiDisksServer
IscsiServersServer IscsiServersServer
JobsServer JobsServer
ManagersServer ManagersServer
StorageAccountCredentialsServer StorageAccountCredentialsServer
StorageDomainsServer StorageDomainsServer
}
ServerFactory is a fake server for instances of the armstorsimple1200series.ClientFactory type.
type ServerFactoryTransport ¶
type ServerFactoryTransport struct {
// contains filtered or unexported fields
}
ServerFactoryTransport connects instances of armstorsimple1200series.ClientFactory to instances of ServerFactory. Don't use this type directly, use NewServerFactoryTransport instead.
func NewServerFactoryTransport ¶
func NewServerFactoryTransport(srv *ServerFactory) *ServerFactoryTransport
NewServerFactoryTransport creates a new instance of ServerFactoryTransport with the provided implementation. The returned ServerFactoryTransport instance is connected to an instance of armstorsimple1200series.ClientFactory via the azcore.ClientOptions.Transporter field in the client's constructor parameters.
type StorageAccountCredentialsServer ¶
type StorageAccountCredentialsServer struct {
// BeginCreateOrUpdate is the fake for method StorageAccountCredentialsClient.BeginCreateOrUpdate
// HTTP status codes to indicate success: http.StatusOK, http.StatusAccepted
BeginCreateOrUpdate func(ctx context.Context, credentialName string, resourceGroupName string, managerName string, storageAccount armstorsimple1200series.StorageAccountCredential, options *armstorsimple1200series.StorageAccountCredentialsClientBeginCreateOrUpdateOptions) (resp azfake.PollerResponder[armstorsimple1200series.StorageAccountCredentialsClientCreateOrUpdateResponse], errResp azfake.ErrorResponder)
// BeginDelete is the fake for method StorageAccountCredentialsClient.BeginDelete
// HTTP status codes to indicate success: http.StatusAccepted, http.StatusNoContent
BeginDelete func(ctx context.Context, credentialName string, resourceGroupName string, managerName string, options *armstorsimple1200series.StorageAccountCredentialsClientBeginDeleteOptions) (resp azfake.PollerResponder[armstorsimple1200series.StorageAccountCredentialsClientDeleteResponse], errResp azfake.ErrorResponder)
// Get is the fake for method StorageAccountCredentialsClient.Get
// HTTP status codes to indicate success: http.StatusOK
Get func(ctx context.Context, credentialName string, resourceGroupName string, managerName string, options *armstorsimple1200series.StorageAccountCredentialsClientGetOptions) (resp azfake.Responder[armstorsimple1200series.StorageAccountCredentialsClientGetResponse], errResp azfake.ErrorResponder)
// NewListByManagerPager is the fake for method StorageAccountCredentialsClient.NewListByManagerPager
// HTTP status codes to indicate success: http.StatusOK
NewListByManagerPager func(resourceGroupName string, managerName string, options *armstorsimple1200series.StorageAccountCredentialsClientListByManagerOptions) (resp azfake.PagerResponder[armstorsimple1200series.StorageAccountCredentialsClientListByManagerResponse])
}
StorageAccountCredentialsServer is a fake server for instances of the armstorsimple1200series.StorageAccountCredentialsClient type.
type StorageAccountCredentialsServerTransport ¶
type StorageAccountCredentialsServerTransport struct {
// contains filtered or unexported fields
}
StorageAccountCredentialsServerTransport connects instances of armstorsimple1200series.StorageAccountCredentialsClient to instances of StorageAccountCredentialsServer. Don't use this type directly, use NewStorageAccountCredentialsServerTransport instead.
func NewStorageAccountCredentialsServerTransport ¶
func NewStorageAccountCredentialsServerTransport(srv *StorageAccountCredentialsServer) *StorageAccountCredentialsServerTransport
NewStorageAccountCredentialsServerTransport creates a new instance of StorageAccountCredentialsServerTransport with the provided implementation. The returned StorageAccountCredentialsServerTransport instance is connected to an instance of armstorsimple1200series.StorageAccountCredentialsClient via the azcore.ClientOptions.Transporter field in the client's constructor parameters.
type StorageDomainsServer ¶
type StorageDomainsServer struct {
// BeginCreateOrUpdate is the fake for method StorageDomainsClient.BeginCreateOrUpdate
// HTTP status codes to indicate success: http.StatusOK, http.StatusAccepted
BeginCreateOrUpdate func(ctx context.Context, storageDomainName string, resourceGroupName string, managerName string, storageDomain armstorsimple1200series.StorageDomain, options *armstorsimple1200series.StorageDomainsClientBeginCreateOrUpdateOptions) (resp azfake.PollerResponder[armstorsimple1200series.StorageDomainsClientCreateOrUpdateResponse], errResp azfake.ErrorResponder)
// BeginDelete is the fake for method StorageDomainsClient.BeginDelete
// HTTP status codes to indicate success: http.StatusAccepted, http.StatusNoContent
BeginDelete func(ctx context.Context, storageDomainName string, resourceGroupName string, managerName string, options *armstorsimple1200series.StorageDomainsClientBeginDeleteOptions) (resp azfake.PollerResponder[armstorsimple1200series.StorageDomainsClientDeleteResponse], errResp azfake.ErrorResponder)
// Get is the fake for method StorageDomainsClient.Get
// HTTP status codes to indicate success: http.StatusOK
Get func(ctx context.Context, storageDomainName string, resourceGroupName string, managerName string, options *armstorsimple1200series.StorageDomainsClientGetOptions) (resp azfake.Responder[armstorsimple1200series.StorageDomainsClientGetResponse], errResp azfake.ErrorResponder)
// NewListByManagerPager is the fake for method StorageDomainsClient.NewListByManagerPager
// HTTP status codes to indicate success: http.StatusOK
NewListByManagerPager func(resourceGroupName string, managerName string, options *armstorsimple1200series.StorageDomainsClientListByManagerOptions) (resp azfake.PagerResponder[armstorsimple1200series.StorageDomainsClientListByManagerResponse])
}
StorageDomainsServer is a fake server for instances of the armstorsimple1200series.StorageDomainsClient type.
type StorageDomainsServerTransport ¶
type StorageDomainsServerTransport struct {
// contains filtered or unexported fields
}
StorageDomainsServerTransport connects instances of armstorsimple1200series.StorageDomainsClient to instances of StorageDomainsServer. Don't use this type directly, use NewStorageDomainsServerTransport instead.
func NewStorageDomainsServerTransport ¶
func NewStorageDomainsServerTransport(srv *StorageDomainsServer) *StorageDomainsServerTransport
NewStorageDomainsServerTransport creates a new instance of StorageDomainsServerTransport with the provided implementation. The returned StorageDomainsServerTransport instance is connected to an instance of armstorsimple1200series.StorageDomainsClient via the azcore.ClientOptions.Transporter field in the client's constructor parameters.
Source Files
¶
- accesscontrolrecords_server.go
- alerts_server.go
- availableprovideroperations_server.go
- backups_server.go
- backupschedulegroups_server.go
- chapsettings_server.go
- devices_server.go
- fileservers_server.go
- fileshares_server.go
- internal.go
- iscsidisks_server.go
- iscsiservers_server.go
- jobs_server.go
- managers_server.go
- server_factory.go
- storageaccountcredentials_server.go
- storagedomains_server.go
- time_rfc3339.go